
from loguru import logger
import easytrader
from easytrader import grid_strategies
from flask import jsonify
from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.constant.db_name_constant as db_name_constant
from trader.common.terminal_enum import TerminalEnum

mongodb_util = MongodbUtil('27017')
from functools import lru_cache


@lru_cache(maxsize=None)
def get_trader_user():
    query = {'type': TerminalEnum.EASY_TRADER.terminal_code}
    stock_account_info_df = mongodb_util.find_query_data(db_name_constant.STOCK_ACCOUNT_INFO, query)
    exe_path = list(stock_account_info_df['exe_path'])[0]
    data_path = list(stock_account_info_df['data_path'])[0]
    user = easytrader.use('ths')
    user.connect(exe_path)
    user.grid_strategy = grid_strategies.Xls
    user.grid_strategy_instance.tmp_folder = data_path
    return user


# 下单
def order_buy(symbol, buy_price, buy_volume):
    user = get_trader_user()
    logger.warning("买入代码:{},买入价格:{},买入数量:{}", symbol, buy_price, buy_volume)
    user.enable_type_keys_for_editor()
    buy_result = user.buy(symbol, buy_price, buy_volume)

    return buy_result


# 自动一键打新
def auto_ipo_buy():
    user = get_trader_user()
    return user.auto_ipo()


# 获取持仓
def get_position():
    user = get_trader_user()
    result = user.position
    return jsonify(result)


# 卖出
def order_sell(symbol, sell_price, sell_volume):
    logger.warning("卖出代码:{},卖出价格:{},卖出数量:{}", symbol, sell_price, sell_volume)
    user = get_trader_user()
    user.enable_type_keys_for_editor()
    sell_result = user.sell(symbol, sell_price, sell_volume)
    return sell_result


# 取消
def order_cancel(entrust_no):
    user = get_trader_user()
    user.enable_type_keys_for_editor()
    cancel_result = user.cancel_entrust(entrust_no)
    return cancel_result


# 获取资金
def get_balance():
    user = get_trader_user()
    balance_info = user.balance
    return balance_info


if __name__ == '__main__':
    get_balance()




from flask import Blueprint
from flask import request
import trader.easy_trader.easy_trader_service as easy_trader_service
import trader.qmt.qmt_service as qmt_service
from trader.common.terminal_enum import TerminalEnum
import trader.qmt.qmt_auto_login as qmt_auto_login
import trader.easy_trader.ths_auto_login as ths_auto_login

api_blueprint_trade = Blueprint("api_blueprint_trade", __name__)


# 买入
@api_blueprint_trade.route('/buy', methods=['POST'])
def trade_buy():
    symbol = request.json.get("symbol")
    buy_price = request.json.get("buy_price")
    buy_volume = request.json.get("buy_volume")
    terminal = request.json.get("terminal")
    if terminal == TerminalEnum.EASY_TRADER.terminal_code:
        return easy_trader_service.order_buy(symbol, buy_price, buy_volume)
    elif terminal == TerminalEnum.QMT.terminal_code:
        return qmt_service.order_buy(symbol, buy_price, buy_volume)
    else:
        '''
        默认easy_trader
        '''
        return easy_trader_service.order_buy(symbol, buy_price, buy_volume)


# 卖出
@api_blueprint_trade.route('/sell', methods=['POST'])
def trade_sell():
    symbol = request.json.get("symbol")
    sell_price = request.json.get("sell_price")
    sell_volume = request.json.get("sell_volume")
    terminal = request.json.get("terminal")
    if terminal == TerminalEnum.EASY_TRADER.terminal_code:
        return easy_trader_service.order_sell(symbol, sell_price, sell_volume)
    elif terminal == TerminalEnum.QMT.terminal_code:
        return qmt_service.order_sell(symbol, sell_price, sell_volume)
    else:
        '''
        默认easy_trader
        '''
        return easy_trader_service.order_sell(symbol, sell_price, sell_volume)


# 自动一键打新
@api_blueprint_trade.route('/auto/ipo/buy', methods=['POST'])
def auto_ipo_buy():
    terminal = request.json.get("terminal")
    if terminal == TerminalEnum.EASY_TRADER.terminal_code:
        return easy_trader_service.auto_ipo_buy()
    elif terminal == TerminalEnum.QMT.terminal_code:
        return qmt_service.auto_ipo_buy()
    else:
        '''
        默认easy_trader
        '''
        return easy_trader_service.order_buy()


# 获取仓位
@api_blueprint_trade.route('/position', methods=['POST'])
def get_position():
    terminal = request.json.get("terminal")
    if terminal == TerminalEnum.EASY_TRADER.terminal_code:
        return easy_trader_service.get_position()
    elif terminal == TerminalEnum.QMT.terminal_code:
        return qmt_service.get_position()
    else:
        '''
        默认easy_trader
        '''
        return easy_trader_service.get_position()


# 撤单
@api_blueprint_trade.route('/cancel', methods=['POST'])
def order_cancel():
    terminal = request.json.get("terminal")
    entrust_no = request.json.get("entrust_no")
    symbol = request.json.get("symbol")
    if terminal == TerminalEnum.EASY_TRADER.terminal_code:
        return easy_trader_service.order_cancel(entrust_no)
    elif terminal == TerminalEnum.QMT.terminal_code:
        return qmt_service.order_cancel(entrust_no, symbol)
    else:
        '''
        默认easy_trader
        '''
        return easy_trader_service.order_cancel(entrust_no)


# 客户端自动登陆
@api_blueprint_trade.route('/auto/login', methods=['POST'])
def auto_login():
    terminal = request.json.get("terminal")
    if terminal == TerminalEnum.EASY_TRADER.terminal_code:
        return ths_auto_login.ths_auto_login()
    elif terminal == TerminalEnum.QMT.terminal_code:
        return qmt_auto_login.qmt_auto_login()


# 获取账户余额
@api_blueprint_trade.route('/account/balance', methods=['GET'])
def account_balance():
    terminal = request.json.get("terminal")
    if terminal == TerminalEnum.EASY_TRADER.terminal_code:
        return easy_trader_service.get_balance()
    elif terminal == TerminalEnum.QMT.terminal_code:
        return qmt_auto_login.qmt_auto_login()




from trader.utils.windows_util import get_all_process
import time
import pyautogui as pa
import pywinauto as pw
from loguru import logger

from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.constant.db_name_constant as db_name_constant
from trader.common.terminal_enum import TerminalEnum
mongodb_util = MongodbUtil('27017')


def qmt_auto_login():
    query = {'type': TerminalEnum.QMT.terminal_code}
    stock_account_info_df = mongodb_util.find_query_data(db_name_constant.STOCK_ACCOUNT_INFO, query)
    user = list(stock_account_info_df['account'])[0]
    password = list(stock_account_info_df['password'])[0]
    connect_path = list(stock_account_info_df['exe_path'])[0]
    all_process_df = get_all_process()
    # 查看运行的是mini qmt 还是qmt
    is_running = all_process_df.loc[all_process_df['process_name'] == 'XtMiniQmt.exe'].shape[0] > 0
    if is_running:
        logger.warning("QMT终端已经在运行中")
        return {"result": 'success'}
    app = pw.Application(backend='uia').start(connect_path, timeout=10)
    app.top_window()
    pa.typewrite(user)
    time.sleep(1)
    pa.hotkey('tab')
    pa.typewrite(password)
    pa.hotkey('enter')
    return {"result": 'success'}


if __name__ == '__main__':
    qmt_auto_login()
